pub struct Directive<A = String> {
pub action: A,
pub kind: Option<String>,
pub name: Pattern,
pub path: Option<Pattern>,
pub note: Option<String>,
}Expand description
One parsed directive: ACTION:[<KIND>]NAME[@PATH][=NOTE].
Generic over the action vocabulary A, defaulting to String. Matching (Directive::matches)
is independent of A.
Fields
action: AThe resolved action.
kind: Option<String>Optional KIND filter (<*>/omitted ⇒ None ⇒ any). Stored un-escaped; matched exactly.
name: PatternThe (required) NAME glob.
path: Option<Pattern>The optional @PATH glob.
note: Option<String>The optional =NOTE — free text, taken raw.
Implementations
Sourceimpl<A> Directive<A>
impl<A> Directive<A>
Sourcepub fn matches(&self, t: &impl Target) -> bool
pub fn matches(&self, t: &impl Target) -> bool
Does this directive apply to t?
- KIND (if set) must equal
t.qualifier()exactly; - NAME must match (the target decides over which of its names, via
Target::matches_name); - PATH (if set) must match one of the target’s scopes (
Target::matches_scope).
Action-independent: a caller that wants to ignore some actions (e.g. a set config
directive) filters those out before matching.